=======
Credits
=======

Development Lead
----------------

* Mingze Huang, Christian L. Müller, Irina Gaynanova <mingzehuang@gmail.com, christian.mueller@stat.uni-muenchen.de, irinag@stat.tamu.edu>

Contributors
------------

* Mingze Huang, Christian L. Müller, Irina Gaynanova <mingzehuang@gmail.com, christian.mueller@stat.uni-muenchen.de, irinag@stat.tamu.edu>

